@@ -29,6 +29,7 @@ Sjis-JA - Source code filter to escape ShiftJIS (Japanese document)
       perl510  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
       perl512  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
       perl514  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      perl516  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
       perl64   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
 
       ? * găChJ[h̎w肪ł܂
@@ -51,6 +52,7 @@ Sjis-JA - Source code filter to escape ShiftJIS (Japanese document)
       Sjis::substr(...);
       Sjis::index(...);
       Sjis::rindex(...);
+      CORE::chop(...);
 
    Perl5.6 G~[V(perl5.005̏ꍇ)
       use warnings;
@@ -84,12 +86,11 @@ jperl ͕svɂȂƌĂ܂B
 {ɂāAėp^Rs[^̓óAp[\iRs[^̓R[
 hѓóAɂ͌gѓdbɎ܂ŁAShiftJIS {ƂR[h
 LgĂ܂B̃\tgEFA͂ ShiftJIS 𒼐ڈ܂B
-Latin-1 ܂B̂ UTF8 tO͂܂B
+Latin-1 ܂B̂ UTF8 tO͎g܂B
 ̃\tgEFA Shift_JIS, Windows-31J, CP932, MacJapanese, SJIS(R90),
 Shift_JISX0213, Shift_JIS-2004 Ȃǂ ShiftJIS ̈Ƃł܂B
 ̕ł͂𑍏̂ ShiftJIS Ƃŕ\Ă܂(u_vȂ)B
 
-Gȉ@͖蕡Gɂ܂B
 ȂGR[h̖肩GXP[v܂񂩁H
 
 =head1 ЂƂ̖(݂炢)
@@ -120,7 +121,7 @@ ftp://ftp.oreilly.co.jp/pcjp98/watanabe/jperlconf.ppt
 \[XR[htB^łBGXP[vɂĕR[hω邱Ƃ͂
 ܂B
 
-̃\tgEFA͈ȉ̓܂B
+\tgEFAȉ̂Ƃwł̃\tgEFA͍쐬܂B
 
 =over 2
 
@@ -128,7 +129,7 @@ ftp://ftp.oreilly.co.jp/pcjp98/watanabe/jperlconf.ppt
 
 =item * jcode.pl ̂悤ȍő̈ڐA
 
-=item * JPerl ̂悤ɃVtgJIŜ܂܈AUTF8tOȂ
+=item * JPerl ̂悤ɃVtgJIŜ܂܈AUTF8tOgȂ
 
 =item * Encode W[̂悤 Perl 1̃C^v^̂܂
 
@@ -192,6 +193,7 @@ GXP[v_قȂ܂B
    perl510  pmake.bat install --- perl5.010 ɃCXg[܂
    perl512  pmake.bat install --- perl5.012 ɃCXg[܂
    perl514  pmake.bat install --- perl5.014 ɃCXg[܂
+   perl516  pmake.bat install --- perl5.016 ɃCXg[܂
    perl64   pmake.bat install --- perl64    ɃCXg[܂
 
    VXe strict.pm Ȃꍇ͕t strict.pm_  strict.pm Ƀl[
@@ -212,6 +214,7 @@ GXP[v_قȂ܂B
    perl510.bat           --- ϐ PATH ̐ݒȂ perl5.10 TĎs
    perl512.bat           --- ϐ PATH ̐ݒȂ perl5.12 TĎs
    perl514.bat           --- ϐ PATH ̐ݒȂ perl5.14 TĎs
+   perl516.bat           --- ϐ PATH ̐ݒȂ perl5.16 TĎs
    perl64.bat            --- ϐ PATH ̐ݒȂ perl64   TĎs
    strict.pm_            --- _~[ strict.pm
    warnings.pm_          --- warnings.pm ̊ȈՔ
@@ -279,36 +282,121 @@ GXP[v_قȂ܂B
   in the perl     "`/"    [83] [5c]
   -----------------------------------------
 
+=head1 K\ւ̃}`oCgAJ[O̒ǉ
+
+Sjis.pm ͐K\̐擪Ƀ}`oCgAJ[Ot܂B
+
+  --------------------------------------------------------------------------------
+  O                  
+  --------------------------------------------------------------------------------
+  m/regexp/               m/@{Esjis::anchor}(?:regexp).../
+  --------------------------------------------------------------------------------
+
+=head1 2INebg̃GXP[v
+
+Sjis.pm ͐K\̃}`oCg̑2INebgGXP[v܂B
+
+  --------------------------------------------------------------------------------
+  O                  
+  --------------------------------------------------------------------------------
+  m{...`/...}             m{...`/\...}
+  --------------------------------------------------------------------------------
+
+=head1 K\̃}`oCg̈ɂ
+
+Sjis.pm ̓}`oCgւ̗ʎwqAу}`oCg̃JX^NX
+NX^O܂B܂NbVbN Perl NXAPOSIX X^C̕
+NX}`oCgΉłɏ܂B
+
+  --------------------------------------------------------------------------------
+  O                  
+  --------------------------------------------------------------------------------
+  m/...MULTIOCT+.../      m/...(?:MULTIOCT)+.../
+  m/...[AN-EM].../        m/...(?:A[N-Z]|[B-D][A-Z]|E[A-M]).../
+  m/...\D.../             m/...@{Esjis::eD}.../
+  m/...[[:^digit:]].../   m/...@{Esjis::not_digit}.../
+  --------------------------------------------------------------------------------
+
+=head1 Esjis::ignorecase() ̌Ăяo
+
+Sjis.pm  /i Cq̑ Esjis::ignorecase() ̌ďo܂B
+
+  --------------------------------------------------------------------------------
+  O                  
+  --------------------------------------------------------------------------------
+  m/...$var.../i          m/...@{[Esjis::ignorecase($var)]}.../
+  --------------------------------------------------------------------------------
+
+=head1 w̐K\
+
+/b Cq̂ȂK\͕w̓܂B
+
+  --------------------------------------------------------------------------------
+  O                  
+  --------------------------------------------------------------------------------
+  /regexp/                / LQ @Esjis::matched/
+  m/regexp/               m/ LQ @Esjis::matched/
+  ?regexp?                m? LQ @Esjis::matched?
+  m?regexp?               m? LQ @Esjis::matched?
+  s/regexp//              ($_ =~ m/ LQ @Esjis::matched/) ?
+                          eval{ Esjis::s_matched(); local $^W=0; my $__r=qq//; $_="${1}$__r$'"; 1 } :
+                          undef
+  split(/regexp/)         Esjis::split(qr/regexp/)
+  split(m/regexp/)        Esjis::split(qr/regexp/)
+  split(qr/regexp/)       Esjis::split(qr/regexp/)
+  qr/regexp/              qr/ LQ @Esjis::matched/
+  --------------------------------------------------------------------------------
+
+=head1 oCgw̐K\
+
+/b CqtK\̓oCgw̓܂B
+
+  --------------------------------------------------------------------------------
+  O                  
+  --------------------------------------------------------------------------------
+  /regexp/b               /(?:regexp)@Esjis::matched/
+  m/regexp/b              m/(?:regexp)@Esjis::matched/
+  ?regexp?b               m?regexp@Esjis::matched?
+  m?regexp?b              m?regexp@Esjis::matched?
+  s/regexp//b             ($_ =~ m/(\G[\x00-\xFF]*?)(?:regexp)@Esjis::matched/) ?
+                          eval{ Esjis::s_matched(); local $^W=0; my $__r=qq//; $_="${1}$__r$'"; 1 } :
+                          undef
+  split(/regexp/b)        split(qr/regexp/)
+  split(m/regexp/b)       split(qr/regexp/)
+  split(qr/regexp/b)      split(qr/regexp/)
+  qr/regexp/b             qr/(?:regexp)@Esjis::matched/
+  --------------------------------------------------------------------------------
+
 =head1 NX̃GXP[v
 
 ߋperlƂ̌݊ۂ߂ɕNX͈ȉ̂悤ɍĒ`Ă܂B
 
-  ---------------------------------------------------------------------------
+  ---------------------------------------------------------------
   escape        class
-  ---------------------------------------------------------------------------
-   .            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x0A])
-                (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC])     (/s Cq)
+  ---------------------------------------------------------------
+   .            @{Esjis::dot}
+                @{Esjis::dot_s}    (/s Cq)
   \d            [0-9]
   \s            [\x09\x0A\x0C\x0D\x20]
   \w            [0-9A-Z_a-z]
-  \D            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC0-9])
-  \S            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x09\x0A\x0C\x0D\x20])
-  \W            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC0-9A-Z_a-z])
+  \D            @{Esjis::eD}
+  \S            @{Esjis::eS}
+  \W            @{Esjis::eW}
   \h            [\x09\x20]
   \v            [\x0C\x0A\x0D]
-  \H            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x09\x20])
-  \V            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x0C\x0A\x0D])
+  \H            @{Esjis::eH}
+  \V            @{Esjis::eV}
   \C            [\x00-\xFF]
   \X            X (̉pAX ł)
-  \R            (?:\x0D\x0A|[\x0A\x0D])
-  \N            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x0A])
-  ---------------------------------------------------------------------------
+  \R            @{Esjis::eR}
+  \N            @{Esjis::eN}
+  ---------------------------------------------------------------
 
 l POSIX X^C̕NXĒ`Ă܂B
 
-  ---------------------------------------------------------------------------
+  ---------------------------------------------------------------
   escape        class
-  ---------------------------------------------------------------------------
+  ---------------------------------------------------------------
   [:alnum:]     [\x30-\x39\x41-\x5A\x61-\x7A]
   [:alpha:]     [\x41-\x5A\x61-\x7A]
   [:ascii:]     [\x00-\x7F]
@@ -325,94 +413,67 @@ l POSIX X^C̕NXĒ`Ă܂B
                 [\x41-\x5A\x61-\x7A]     (/i Cq)
   [:word:]      [\x30-\x39\x41-\x5A\x5F\x61-\x7A]
   [:xdigit:]    [\x30-\x39\x41-\x46\x61-\x66]
-  [:^alnum:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x30-\x39\x41-\x5A\x61-\x7A])
-  [:^alpha:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x41-\x5A\x61-\x7A])
-  [:^ascii:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x00-\x7F])
-  [:^blank:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x09\x20])
-  [:^cntrl:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x00-\x1F\x7F])
-  [:^digit:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x30-\x39])
-  [:^graph:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x21-\x7F])
-  [:^lower:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x61-\x7A])
-                (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC])           (/i Cq)
-  [:^print:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x20-\x7F])
-  [:^punct:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x21-\x2F\x3A-\x3F\x40\x5B-\x5F\x60\x7B-\x7E])
-  [:^space:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x09\x0A\x0B\x0C\x0D\x20])
-  [:^upper:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x41-\x5A])
-                (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC])           (/i Cq)
-  [:^word:]     (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x30-\x39\x41-\x5A\x5F\x61-\x7A])
-  [:^xdigit:]   (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x30-\x39\x41-\x46\x61-\x66])
-  ---------------------------------------------------------------------------
+  [:^alnum:]    @{Esjis::not_alnum}
+  [:^alpha:]    @{Esjis::not_alpha}
+  [:^ascii:]    @{Esjis::not_ascii}
+  [:^blank:]    @{Esjis::not_blank}
+  [:^cntrl:]    @{Esjis::not_cntrl}
+  [:^digit:]    @{Esjis::not_digit}
+  [:^graph:]    @{Esjis::not_graph}
+  [:^lower:]    @{Esjis::not_lower}
+                @{Esjis::not_lower_i}    (/i Cq)
+  [:^print:]    @{Esjis::not_print}
+  [:^punct:]    @{Esjis::not_punct}
+  [:^space:]    @{Esjis::not_space}
+  [:^upper:]    @{Esjis::not_upper}
+                @{Esjis::not_upper_i}    (/i Cq)
+  [:^word:]     @{Esjis::not_word}
+  [:^xdigit:]   @{Esjis::not_xdigit}
+  ---------------------------------------------------------------
 
 l \b  \B ߋperlƂ̌݊ۂ߂ɍĒ`Ă܂B
 
-  ---------------------------------------------------------------------------
-  escape        class
-  ---------------------------------------------------------------------------
-  \b            (?:\A(?=[0-9A-Z_a-z])|(?<=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF])(?=[0-9A-Z_a-z])|(?<=[0-9A-Z_a-z])(?=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF]|\z))
-  \B            (?:(?<=[0-9A-Z_a-z])(?=[0-9A-Z_a-z])|(?<=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF])(?=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF]))
-  ---------------------------------------------------------------------------
+  ---------------------------------------------------------------
+  escape      class
+  ---------------------------------------------------------------
+  \b          @{Esjis::eb}
+  \B          @{Esjis::eB}
+  ---------------------------------------------------------------
 
-=head1 g݊֐̃GXP[v
+t@C Esjis.pm ̒ňȉ̂悤ɒ`Ă܂B
 
-̃\tgEFAɂĊ֐̐擪 'Esjis::' GXP[v܂B
-Esjis::* ֐ Esjis.pm 񋟂܂B
-
-  ---------------------------------
-  O      
-  ---------------------------------
-  length      length
-  substr      substr
-  pos         pos
-  split       Esjis::split
-  tr///       Esjis::tr
-  tr///b      tr///
-  tr///B      tr///
-  y///        Esjis::tr
-  y///b       tr///
-  y///B       tr///
-  chop        Esjis::chop
-  index       Esjis::index
-  rindex      Esjis::rindex
-  lc          Esjis::lc
-  lcfirst     Esjis::lcfirst
-  uc          Esjis::uc
-  ucfirst     Esjis::ucfirst
-  chr         Esjis::chr
-  glob        Esjis::glob
-  lstat       Esjis::lstat
-  opendir     Esjis::opendir
-  stat        Esjis::stat
-  unlink      Esjis::unlink
-  chdir       Esjis::chdir
-  do          Esjis::do
-  require     Esjis::require
-  ---------------------------------
-
-  ------------------------------------------------------------------------------------------------------------------------
-  O                   
-  ------------------------------------------------------------------------------------------------------------------------
-  use Perl::Module;        BEGIN { Esjis::require 'Perl/Module.pm'; Perl::Module->import() if Perl::Module->can('import'); }
-  use Perl::Module @list;  BEGIN { Esjis::require 'Perl/Module.pm'; Perl::Module->import(@list) if Perl::Module->can('import'); }
-  use Perl::Module ();     BEGIN { Esjis::require 'Perl/Module.pm'; }
-  no Perl::Module;         BEGIN { Esjis::require 'Perl/Module.pm'; Perl::Module->unimport() if Perl::Module->can('unimport'); }
-  no Perl::Module @list;   BEGIN { Esjis::require 'Perl/Module.pm'; Perl::Module->unimport(@list) if Perl::Module->can('unimport'); }
-  no Perl::Module ();      BEGIN { Esjis::require 'Perl/Module.pm'; }
-  ------------------------------------------------------------------------------------------------------------------------
-
-=head1 bytes::* ֐̃AGXP[v
-
-̃\tgEFAɂ bytes::* ֐̐擪 'bytes::' 菜܂B
-
-  ------------------------------------
-  O           
-  ------------------------------------
-  bytes::chr       chr
-  bytes::index     index
-  bytes::length    length
-  bytes::ord       ord
-  bytes::rindex    rindex
-  bytes::substr    substr
-  ------------------------------------
+  ---------------------------------------------------------------------------------------------------------------------------------------------------------
+  class                    Definition
+  ---------------------------------------------------------------------------------------------------------------------------------------------------------
+  @{Esjis::anchor}         qr{\G(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC])*?}
+  @{Esjis::dot}            qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x0A])}
+  @{Esjis::dot_s}          qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC])}
+  @{Esjis::eD}             qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC0-9])}
+  @{Esjis::eS}             qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x09\x0A\x0C\x0D\x20])}
+  @{Esjis::eW}             qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC0-9A-Z_a-z])}
+  @{Esjis::eH}             qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x09\x20])}
+  @{Esjis::eV}             qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x0C\x0A\x0D])}
+  @{Esjis::eR}             qr{(?:\x0D\x0A|[\x0A\x0D])}
+  @{Esjis::eN}             qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x0A])}
+  @{Esjis::not_alnum}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x30-\x39\x41-\x5A\x61-\x7A])}
+  @{Esjis::not_alpha}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x41-\x5A\x61-\x7A])}
+  @{Esjis::not_ascii}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x00-\x7F])}
+  @{Esjis::not_blank}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x09\x20])}
+  @{Esjis::not_cntrl}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x00-\x1F\x7F])}
+  @{Esjis::not_digit}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x30-\x39])}
+  @{Esjis::not_graph}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x21-\x7F])}
+  @{Esjis::not_lower}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x61-\x7A])}
+  @{Esjis::not_lower_i}    qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC])}
+  @{Esjis::not_print}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x20-\x7F])}
+  @{Esjis::not_punct}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x21-\x2F\x3A-\x3F\x40\x5B-\x5F\x60\x7B-\x7E])}
+  @{Esjis::not_space}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x09\x0A\x0B\x0C\x0D\x20])}
+  @{Esjis::not_upper}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x41-\x5A])}
+  @{Esjis::not_upper_i}    qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC])}
+  @{Esjis::not_word}       qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x30-\x39\x41-\x5A\x5F\x61-\x7A])}
+  @{Esjis::not_xdigit}     qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x30-\x39\x41-\x46\x61-\x66])}
+  @{Esjis::eb}             qr{(?:\A(?=[0-9A-Z_a-z])|(?<=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF])(?=[0-9A-Z_a-z])|(?<=[0-9A-Z_a-z])(?=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF]|\z))}
+  @{Esjis::eB}             qr{(?:(?<=[0-9A-Z_a-z])(?=[0-9A-Z_a-z])|(?<=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF])(?=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF]))}
+  ---------------------------------------------------------------------------------------------------------------------------------------------------------
 
 =head1 \N, \p, \P, \X ̃AGXP[v
 
@@ -434,41 +495,88 @@ Esjis::* ֐ Esjis.pm 񋟂܂B
   \X               X
   ------------------------------------
 
+=head1 g݊֐̃GXP[v
+
+̃\tgEFAɂĊ֐̐擪 'Esjis::' GXP[v܂B
+Esjis::* ֐ Esjis.pm 񋟂܂B
+
+  --------------------------------------------
+  O                  
+  --------------------------------------------
+  length      length            oCgw
+  substr      substr            oCgw
+  pos         pos               oCgw
+  split       Esjis::split      w
+  tr///       Esjis::tr         w
+  tr///b      tr///             oCgw
+  tr///B      tr///             oCgw
+  y///        Esjis::tr         w
+  y///b       tr///             oCgw
+  y///B       tr///             oCgw
+  chop        Esjis::chop       w
+  index       Esjis::index      w
+  rindex      Esjis::rindex     w
+  lc          Esjis::lc         w
+  lcfirst     Esjis::lcfirst    w
+  uc          Esjis::uc         w
+  ucfirst     Esjis::ucfirst    w
+  chr         Esjis::chr        w
+  glob        Esjis::glob       w
+  lstat       Esjis::lstat      w
+  opendir     Esjis::opendir    w
+  stat        Esjis::stat       w
+  unlink      Esjis::unlink     w
+  chdir       Esjis::chdir      w
+  do          Esjis::do         w
+  require     Esjis::require    w
+  --------------------------------------------
+
+  ------------------------------------------------------------------------------------------------------------------------
+  O                   
+  ------------------------------------------------------------------------------------------------------------------------
+  use Perl::Module;        BEGIN { Esjis::require 'Perl/Module.pm'; Perl::Module->import() if Perl::Module->can('import'); }
+  use Perl::Module @list;  BEGIN { Esjis::require 'Perl/Module.pm'; Perl::Module->import(@list) if Perl::Module->can('import'); }
+  use Perl::Module ();     BEGIN { Esjis::require 'Perl/Module.pm'; }
+  no Perl::Module;         BEGIN { Esjis::require 'Perl/Module.pm'; Perl::Module->unimport() if Perl::Module->can('unimport'); }
+  no Perl::Module @list;   BEGIN { Esjis::require 'Perl/Module.pm'; Perl::Module->unimport(@list) if Perl::Module->can('unimport'); }
+  no Perl::Module ();      BEGIN { Esjis::require 'Perl/Module.pm'; }
+  ------------------------------------------------------------------------------------------------------------------------
+
 =head1 t@CeXgZq̃GXP[v
 
 ̃\tgEFAɂĉZq '-'  'Esjis::' ɏ܂B
 
-  ---------------------------------
-  O      
-  ---------------------------------
-  -r          Esjis::r
-  -w          Esjis::w
-  -x          Esjis::x
-  -o          Esjis::o
-  -R          Esjis::R
-  -W          Esjis::W
-  -X          Esjis::X
-  -O          Esjis::O
-  -e          Esjis::e
-  -z          Esjis::z
-  -f          Esjis::f
-  -d          Esjis::d
-  -l          Esjis::l
-  -p          Esjis::p
-  -S          Esjis::S
-  -b          Esjis::b
-  -c          Esjis::c
-  -t          -t
-  -u          Esjis::u
-  -g          Esjis::g
-  -k          Esjis::k
-  -T          Esjis::T
-  -B          Esjis::B
-  -s          Esjis::s
-  -M          Esjis::M
-  -A          Esjis::A
-  -C          Esjis::C
-  ---------------------------------
+  -------------------------------------------------------------------------------
+  O          
+  -------------------------------------------------------------------------------
+  -r        Esjis::r     uid/gid œǂݏo
+  -w        Esjis::w     uid/gid ŏ݉
+  -x        Esjis::x     uid/gid Ŏs
+  -o        Esjis::o     uid L
+  -R        Esjis::R     uid/gid œǂݏo
+  -W        Esjis::W     uid/gid ŏ݉
+  -X        Esjis::X     uid/gid Ŏs
+  -O        Esjis::O     uid/gid L
+  -e        Esjis::e    t@C݂
+  -z        Esjis::z    t@C̒ 0 ł
+  -f        Esjis::f    ʂ̃t@Cł
+  -d        Esjis::d    fBNgł
+  -l        Esjis::l    V{bNNł
+  -p        Esjis::p    OtpCv(FIFO)ł
+  -S        Esjis::S    \Pbgł
+  -b        Esjis::b    ubNXyVt@Cł
+  -c        Esjis::c    LN^XyVt@Cł
+  -t        -t          t@Cnh tty ɑ΂ăI[vĂ
+  -u        Esjis::u    setuid rbgZbgĂ
+  -g        Esjis::g    setgid rbgZbgĂ
+  -k        Esjis::k    sticky rbgZbgĂ
+  -T        Esjis::T    eLXgt@Cł
+  -B        Esjis::B    oCit@Cł(-T Ƃ͋ẗӖ)
+  -s        Esjis::s    t@C̒ 0 ł͂Ȃ(oCgPʂŕԂ)
+  -M        Esjis::M    (sJnƂ)CĂ̓
+  -A        Esjis::A    (sJnƂ)ŌɃANZXĂ̓
+  -C        Esjis::C    (sJnƂ)inode ύXĂ̓
+  -------------------------------------------------------------------------------
 
 perl5.00503 gpĂꍇłt@CeXgZq́uςݏd˂vƂ
 ł܂B
@@ -534,16 +642,6 @@ ẘ֐gꍇ͈ȉ̂悤ɋLqKv܂Bꂼ
 
     Sjis::reverse(@list) ̓XgReLXgł @list ̗vftɕׂ
     XglԂ܂B
-    𗘗pāA~̐𔭐邱Ƃł܂B
-
-    for (Sjis::reverse(1 .. 10)) { ... }
-
-    @list ƂănbVnꍇÃnbV̓tbgȃXgɕϊ
-    B̂Ƃ𗘗p΁Areverse gănbVtɂ(lL[
-    Ђ悤ɂ)Ƃł܂(AׂĂ̒lj[Nł邱ƂO
-    ł)B
-
-    %barfoo = Sjis::reverse(%foobar);
 
     XJ[ReLXgł @list ׂ̂Ă̗vfAŁAShiftJIS 
     Pʂŋtɂ̂Ԃ܂B
@@ -607,11 +705,11 @@ ẘ֐gꍇ͈ȉ̂悤ɋLqKv܂Bꂼ
     $index = Sjis::index($string,$substring);
 
     Sjis::index ́AShiftJIS  $string ̒Ɋ܂܂A1 ShiftJIS 
-     $substr T܂B$string ̒ŁA$substr ŏɏoʒu𕶎P
-    ŐĕԂ܂B$start w肳ĂꍇA$string ̐擪 $start 
-    XLbvʒuA$substr Tn߂܂Bʒu 0 x[XɂƂ
-    ܂B$substr Ȃ΁ASjis::index ֐̓x[X 1 
-    l -1 Ԃ܂BSjis::index gāAŜ𒲂ׂɂ́Â悤ɂ
+     $substring T܂B$string ̒ŁA$substring ŏɏoʒu
+    PʂŐĕԂ܂B$start w肳ĂꍇA$string ̐擪 $start
+    ̕XLbvʒuA$substring Tn߂܂Bʒu 0 x[XƂ
+    Đ܂B$substring Ȃ΁ASjis::index ֐̓x[X 1 
+    l -1 Ԃ܂BSjis::index gāAŜ𒲂ׂɂ́Â悤
     ܂B
 
     $pos = -1;
@@ -626,11 +724,11 @@ ẘ֐gꍇ͈ȉ̂悤ɋLqKv܂Bꂼ
     $rindex = Sjis::rindex($string,$substring);
 
     Sjis::rindex  Sjis::index ƎĂ܂AShiftJIS  $string ̒ŁA
-     $substr Ōɏoʒu𕶎PʂŐĕԂ܂(܂
-    reverse Sjis::index ł)B$substr Ȃ΁A-1 Ԃ܂B$position
-    ɂāAlƂĕԂƂAłËʒuw肷邱Ƃł܂B
-    Sjis::rindex gāAŜ𖖔擪ɌĒׂɂ́Â悤
-    ɂ܂B
+     $substring Ōɏoʒu𕶎PʂŐĕԂ܂(܂
+    reverse Sjis::index ł)B$substring Ȃ΁A-1 Ԃ܂B
+    $position ɂāAlƂĕԂƂAłËʒuw肷邱
+    ł܂BSjis::rindex gāAŜ𖖔擪ɌĒׂ
+    ́Â悤ɂ܂B
 
     $pos = Sjis::length($string);
     while (($pos = Sjis::rindex($string, $lookfor, $pos)) >= 0) {
@@ -640,6 +738,144 @@ ẘ֐gꍇ͈ȉ̂悤ɋLqKv܂Bꂼ
 
 =back
 
+=head1 oCgẘ֐
+
+=over 2
+
+=item * CORE::chop
+
+    $byte = CORE::chop($string);
+    $byte = CORE::chop(@list);
+    $byte = CORE::chop;
+
+    ϐ邢̓oCgϐ̍Ō̃oCg؂藎ƂÃoCglƂ
+    Ԃ܂BCORE::chop Zq́Aɓ̓R[h̖s菜̂
+    pAuZqg(s/\n$//)IłB肽Ƃꂾ
+    Ȃ΁Achomp gقSłBȂȂACORE::chop ͖ɂoCg
+    𖳏Ŏ菜̂ɑ΂āAchomp ͎菜̂IŎ菜łB
+
+    e CORE::chop 邱Ƃ͂ł܂ --- CORE::chop ł͕̂ϐ
+    B
+
+    Ƃĕϐ̃Xg @list ^ƁAXg̊e̍Ō̃oCg؂
+    Ƃ܂:
+
+    @lines = `cat myfile`;
+    CORE::chop @lines;
+
+    ܂߁AӒlȂ΂ǂȂ̂ł CORE::chop 邱Ƃł܂:
+
+    CORE::chop($cwd = `pwd`);
+    CORE::chop($answer = <STDIN>);
+
+    2śA̗Ƃ͈܂:
+
+    $answer = CORE::chop($tmp = <STDIN>); # 
+
+    ̃R[hł́ACORE::chop ́A($tmpɓĂ)cꂽł͂ȂA؂
+    ƂoCgԂ̂ŁA$answer ɂ͉sZbgĂ܂܂BӐ}
+    ʂ𓾂邽߂̕@1́Asubstr gƂł:
+
+    $answer = substr <STDIN>, 0, -1;
+
+    Â悤ɏ̂ʂł:
+
+    CORE::chop($answer = <STDIN>);
+
+    łʓIȃP[Xł́Asubstr gāACORE::chop 邱Ƃł܂:
+
+    $last_byte = CORE::chop($var);
+    $last_byte = substr($var, -1, 1, ""); # 
+
+    炪ł邱Ƃ𗝉Ă܂΁A܂Ƃ߂ CORE::chop sƂł
+    ܂B2ȏ̃oCg܂Ƃ߂Đ؂藎Ƃɂ́Asubstr ӒlƂĎgA
+    󕶎܂B̃R[h $caravan ̍Ō5oCg菜܂:
+
+    substr($caravan, -5) = "";
+
+    ł substr ɕ̒l^邱ƂɂāA(擪ł͂Ȃ)̃I
+    tZbgw肵Ă܂B폜oCgۑ΁A4 substr g
+    5oCg CORE::chop ܂:
+
+    $tail = substr($caravan, -5, 5, "");
+
+    ȗƁAϐ $_ ΏۂƂȂ܂B
+
+=item * CORE::ord
+
+    $ord = CORE::ord($expr);
+
+    CORE::ord($expr)  "use Sjis qw(ord);" ̋Lq̗LɊւ炸A $expr
+    ̐擪̃oCglԂ܂B$expr ȗꂽꍇ $_ ΏۂƂȂ܂B
+    ̊֐͏ɕȂ̒lԂ܂B
+
+    t̒lKvł΁Aunpack('C',$expr) g܂B܂SẴoCgl
+    XgƂĕKvł unpack('C',$expr) Ɏg܂B
+
+=item * CORE::reverse
+
+    @reverse = CORE::reverse(@list);
+    $reverse = CORE::reverse(@list);
+
+    CORE::reverse(@list) ̓XgReLXgł @list ̗vftɕׂ
+    XglԂ܂B
+
+    XJ[ReLXgł "use Sjis qw(ord);" ̋Lq̗LɊւ炸A @list
+    ׂ̂Ă̗vfAŁAoCgPʂŋtɂ̂Ԃ܂B
+
+=item * CORE::index
+
+    $index = CORE::index($string,$substring,$start);
+    $index = CORE::index($string,$substring);
+
+    CORE::index ́AoCg $string ̒Ɋ܂܂A1̃oCg $substring
+    T܂B$string ̒ŁA$substring ŏɏoʒuoCgPʂŐ
+    Ԃ܂B$start w肳ĂꍇA$string ̐擪 $start oCgXLb
+    vʒuA$substring Tn߂܂Bʒu 0 x[XɂĐ܂B
+    $substring Ȃ΁ACORE::index ֐̓x[X 1 l -1
+    Ԃ܂BCORE::index gāAoCgŜ𒲂ׂɂ́Â悤ɂ܂B
+
+    $pos = -1;
+    while (($pos = CORE::index($string, $lookfor, $pos)) > -1) {
+        print "Found at $pos\n";
+        $pos++;
+    }
+
+=item * CORE::rindex
+
+    $rindex = CORE::rindex($string,$substring,$position);
+    $rindex = CORE::rindex($string,$substring);
+
+    CORE::rindex  CORE::index ƎĂ܂AoCg $string ̒ŁAoCg
+     $substring ŌɏoʒuoCgPʂŐĕԂ܂(܂
+    reverse CORE::index ł)B$substring Ȃ΁A-1 Ԃ܂B
+    $position ɂāAlƂĕԂƂAłËʒuw肷邱
+    ł܂BCORE::rindex gāAoCgŜ𖖔擪ɌĒׂ
+    ɂ́Â悤ɂ܂B
+
+    $pos = CORE::length($string);
+    while (($pos = CORE::rindex($string, $lookfor, $pos)) >= 0) {
+        print "Found at $pos\n";
+        $pos--;
+    }
+
+=back
+
+=head1 bytes::* ֐̃AGXP[v
+
+̃\tgEFAɂ bytes::* ֐̐擪 'bytes::' 菜܂B
+
+  -----------------------------------------
+  O               
+  -----------------------------------------
+  bytes::chr       chr       oCgw
+  bytes::index     index     oCgw
+  bytes::length    length    oCgw
+  bytes::ord       ord       oCgw
+  bytes::rindex    rindex    oCgw
+  bytes::substr    substr    oCgw
+  -----------------------------------------
+
 =head1 g݂̕WW[̃GXP[v
 
 Esjis.pm ̐擪 "BEGIN { unshift @INC, '/Perl/site/lib/Sjis' }" sA
@@ -790,7 +1026,13 @@ WW[̃t@C /Perl/site/lib/Sjis ɃRs[ 'use utf8;'
 
 =head1 oOƐ
 
-oO񍐁Apb`}܂B
+̃\tgEFÁA̔\͂sāAeXgďƍ܂BłĂA
+̐K\܂ރ\tgEFÁAx̃oOƂ܂ʂ邱Ƃł܂B
+āAȂ̃XNvgł͂ȂāASjis\tgEFÃoO̂ȂA
+ŏ̃eXgR[hɐ؂l߂ŁA҂܂ŕ񍐂ĒƏ܂B
+
+邢͂ƗLpȃc[ɂ邽߂̂悢ACfBAȂAFƋLĒ
+Ƃ肪łB
 
 =over 2
 
@@ -819,13 +1061,6 @@ oO񍐁Apb`}܂B
     chdir does not work with chr(0x5C) at end of path
     http://bugs.activestate.com/show_bug.cgi?id=81839
 
-=item * ǂ݌
-
-    ǂ݌(Ⴆ (?<=[A-Z]))O̓oCg̑oCgɌă}b`
-    邱Ƃɂ͑ΏĂ܂B
-    Ⴆ΁A'ACE' =~ /(?<=[A-Z])([ACE])/ sƃ}b` $1  'C'
-    ɂȂ܂A͐܂B
-
 =item * ӒlƂĂ Sjis::substr
 
     Sjis::substr  CORE::substr Ƃ͈قȂAӒlƂĈƂł܂B
@@ -834,63 +1069,57 @@ oO񍐁Apb`}܂B
     
     Sjis::substr($string, 13, 4, "JPerl");
 
-=item * ϐ $`  $& ͋@\܂
+=item * ϐ $`  $& gƂ /( K\ŜLv` )/ Kv܂
 
-    ȂȂ΁A
+    ȂȂ΁Aȉ̂悤ɕϊA$1 𗘗p邽߂łB
  
-      'AAABBBCCC' =~ /BBB/;
- 
-    ƂXNvgXP[vƐK\̐擪Ƀ}`oCgAJ[O
-    ̂߂̋LqǉA
- 
-      'AAABBBCCC' =~ /\G(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC])*?(?:BBB)@Esjis::m_matched/;
- 
-    ̕ $& Ɋ܂܂Ă܂łB
-    L̎sʂ͈ȉ̂悤ɂȂ܂B 
-      $'  ''       ('AAA' )
-      $&  'AAABBB' ('BBB' )
-      $`  'CCC'
- 
-    @
-    XNvg̋Lq
- 
-      'AAABBBCCC' =~ /(BBB)/;
- 
-    ̂悤ɂāAK\Ŝ ( ... ) ň͂ŃLv`܂B
-    GXP[ṽXNvg
- 
-      'AAABBBCCC' =~ /\G(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC])*?(?:(BBB))@Esjis::m_matched/;
- 
-    ̂悤ɂȂ̂ŁAsA
- 
-      $1  'BBB'
- 
-    ɂȂA$& ̑Ɏgp邱Ƃł܂B
-
- 邢͈ȉ̕@܂B
-
-  -------------------------------------------------
-  ϐ   ֖@
-  -------------------------------------------------
-  $`     substr(Ώە, 0, $-[0])
-  $&     substr(Ώە, $-[0], $+[0], - $-[0])
-  $'     substr(Ώە, $+[0])
-  -------------------------------------------------
-  uڐ K\ 2 P.349 7.9.3.4 }b`ORs[v
+    -------------------------------------------------------------------------------------------
+    O                         se
+    -------------------------------------------------------------------------------------------
+    $`              Esjis::PREMATCH()    CORE::substr($&,0,CORE::length($&)-CORE::length($1))
+    $PREMATCH       Esjis::PREMATCH()    CORE::substr($&,0,CORE::length($&)-CORE::length($1))
+    ${^PREMATCH}    Esjis::PREMATCH()    CORE::substr($&,0,CORE::length($&)-CORE::length($1))
+    $&              Esjis::MATCH()       $1
+    $MATCH          Esjis::MATCH()       $1
+    ${^MATCH}       Esjis::MATCH()       $1
+    $'              Esjis::POSTMATCH()   $'
+    $POSTMATCH      Esjis::POSTMATCH()   $'
+    ${^POSTMATCH}   Esjis::POSTMATCH()   $'
+    -------------------------------------------------------------------------------------------
 
 =item * K\Kp镶̒̏
 
-    L̂ƂAGXP[v̐K\ɂ̓}`oCgAJ[Ô
-    ߂̋Lqǉ܂A̒Ɋ܂܂ \G ̐󂯂܂B
-    perl5.006, perl5.008, perl5.010, perl5.012, perl5.014 ŎsꍇAΏ
-    32,767oCg𒴂ʒuł̃}b`ׂƂŃ}b`܂B
-    ȂA̍ۂɃG[xo͂܂B
+    Oq̂ƂAGXP[v̐K\ɂ̓}`oCgAJ[Ô
+    ߂̋Lq @{Esjis::anchor} ǉ܂A̒Ɋ܂܂ \G ̐
+    ܂Bperl5.006, perl5.008, perl5.010, perl5.012, perl5.014 Ŏs
+    AΏە32,767oCg𒴂ʒuł̃}b`ׂƂŃ}b`
+    BȂA̍ۂɃG[xo͂܂B
 
     QlN
     Bug #89792
     \G can't treat over 32,767 octets
     http://bugs.activestate.com/show_bug.cgi?id=89792
 
+=item * ??, m?? ̐
+
+    ?? ܂ m?? ̓Ń}`oCgɑ΂ {n,m} {n,} {n} * + Ȃǂ̗ʎw
+    qtꍇ́A̕ ( ) ň͂ŋLqKv܂B̌ʁA
+    $1,$2,$3,... ͂Ă܂߁A̋LqCKv܂B
+    Ȃ ?? ܂ m?? ̓f~^ ? Ȃ̂ŁA(?: ) ʎwq ? {n,m}? {n,}?
+    {n}? ͋Lq邱Ƃł܂B
+
+=item * ǂ݌
+
+    ǂ݌(Ⴆ (?<=[A-Z]))O̓oCg̑oCgɌă}b`
+    邱Ƃɂ͑ΏĂ܂B
+    Ⴆ΁A'ACE' =~ /(?<=[A-Z])([ACE])/ sƃ}b` $1  'C'
+    ɂȂ܂A͐܂B
+
+=item * WJƋɂȂ鐳K\̕ϐ
+
+    ̃eƂ͈قȂAK\ɓWJꂽϐ̒l󕶎ł
+    ĂAOɐK\͎g܂B
+
 =item * K\̏Cq /a /d /l /u
 
     ̃\tgEFÃRZvg͕̕𓯎ɗpȂ悤ɂ
@@ -1478,8 +1707,18 @@ V@ŖƂȂĂ邱Ƃ UTF8 tO͎ۂ̕̕ƈvȂ
 łBōXNvg͂̃fobȎO UTF8 tOɂăfobOȂ
 ΂Ȃ܂B
 
-Ő̂̕@ɖ߂ƂɂāAǂ̂悤ɉ̂ Programming Perl, 3rd ed.
-(M vO~OPerl 3) 402y[Wxp܂傤B
+  ̃\tgEFAɂ񏈗f
+ 
+    +--------------------------------------------+
+    |       Text strings as Binary strings       |
+    |       Binary strings as Text strings       |
+    +--------------------------------------------+
+    |              Not UTF8 Flagged              |
+    +--------------------------------------------+
+
+ŁÂ̕@ɖ߂ƂɂĂǂ̂悤ɉ̂Aقɂ܂݂ꂽÂ
+Programming Perl, 3rd ed. (M vO~OPerl 3) 402y[Wx
+ЂƂĂ݂܂傤EEEB
 
 zIɂ́Aȉ5̃S[悤ƍlĂ܂B
 
@@ -1567,8 +1806,8 @@ zIɂ́Aȉ5̃S[悤ƍlĂ܂B
     葱ׂłB
 
     JPerl  Perl 𕪊򂳂Ȃ悤ɂ邽߂ɁAC^v^𕪊򂳂܂B
-    ł Perl RA`[̓C^v^̕]łȂ̂ł傤BʓIPerl
-    ꂪ򂷂邱ƂɂȂAR~jeB͏k]VȂ܂B
+    ł Perl RA`[̓C^v^̕]łȂ̂ł傤BʓIɃS[
+    4Ƃ͂͂Perlꂪ򂷂邱ƂɂȂAR~jeB͏k܂B
 
     oCgw perl ͂łɃoCif[^Ƃł邽߁Aw
     perl ʗĂō쐬Kv͂܂B܂̃\tgEFÁAPȂAv
@@ -1590,7 +1829,7 @@ Programming Perl, 3rd ed. ꂽɂ́AUTF8 tO͐܂Ă炸APerl
 ȒPȎdȒPɂł悤ɐ݌vĂ܂B̃\tgEFÂ͓悤
 vO~O񋟂܂B
 
-=head1 Ql
+=head1 QlAN
 
  vO~OPerl 
  By Larry Wall, Tom Christiansen, Randal L. Schwartz, ߓ Ð 
@@ -1613,12 +1852,26 @@ vO~O񋟂܂B
  ISBN 4-87311-097-1
  http://www.oreilly.co.jp/books/4873110971/
 
+ The Perl Language Reference Manual (for Perl version 5.12.1)
+ by Larry Wall and others
+ Paperback (6"x9"), 724 pages
+ Retail Price: $39.95 (pound 29.95 in UK)
+ ISBN-13: 978-1-906966-02-7
+ http://www.network-theory.co.uk/perl/language/
+
+ Perl Pocket Reference, 5th Edition
+ By Johan Vromans
+ Publisher: O'Reilly Media
+ Released: July 2011
+ Pages: 102
+ http://shop.oreilly.com/product/0636920018476.do
+
  Programming Perl, 4th Edition
  By: Tom Christiansen, brian d foy, Larry Wall, Jon Orwant
  Publisher: O'Reilly Media
  Formats: Print, Ebook, Safari Books Online
- Released: February 2012
- Pages: 1054
+ Released: March 2012
+ Pages: 1130
  Print ISBN: 978-0-596-00492-7 | ISBN 10: 0-596-00492-3
  Ebook ISBN: 978-1-4493-9890-3 | ISBN 10: 1-4493-9890-1
  http://shop.oreilly.com/product/9780596004927.do
@@ -1748,86 +2001,6 @@ vO~O񋟂܂B
  YAMAGAKI Norio, }`oCgƍpLI[g}gVXe
  http://www.wipo.int/pctdb/ja/wo.jsp?WO=2009116646&IA=JP2009055515
 
- ֘A\tgEFA
- http://search.cpan.org/dist/jacode/
- http://search.cpan.org/dist/Char/
-
- BackPAN
- http://backpan.perl.org/authors/id/I/IN/INA/
-
-=head1 ӎ
-
-̃\tgEFÁAȉ̕X̍쐬\tgEFAѕ̂ɂ쐬
-܂BSĂ̕Ɋӂ܂B
-
- R Ǒ, VtgJIS̃fUC̘b
- ttp://furukawablog.spaces.live.com/Blog/cns!1pmWgsL289nm7Shn7cS0jHzA!2225.entry (N؂)
- ttp://shino.tumblr.com/post/116166805/1981-us-jis
- (擪 'h' tăANZXĂ)
- http://www.wdic.org/w/WDIC/%E3%82%B7%E3%83%95%E3%83%88JIS
-
- Larry Wall, Perl
- http://www.perl.org/
-
- ̑ a, jcode.pl
- ftp://ftp.iij.ad.jp/pub/IIJ/dist/utashiro/perl/
- http://log.utashiro.com/pub/2006/07/jkondo_a580.html
-
- Jeffrey E. F. Friedl, Mastering Regular Expressions
- http://regex.info/
-
- A ms, Shift-JISeLXg𐳂
- http://homepage1.nifty.com/nomenclator/perl/shiftjis.htm
-
- ܂ 䂫Ђ낳, Ruby on Perl(s)
- http://www.rubyist.net/~matz/slides/yapc2006/
-
-  av, jperl[U[̂߂
- http://homepage1.nifty.com/kazuf/jperl.html
-
- Bruce., Unicode in Perl
- http://www.rakunet.org/tsnet/TSabc/18/546.html
-
- a G, WindowsPerl 5.8/5.10gȂ
- http://www.aritia.jp/hizumi/perl/perlwin.html
-
- ˖{ q, Perl/Windowsł̃t@CpX
- http://digit.que.ne.jp/work/wiki.cgi?Perl%E3%83%A1%E3%83%A2%2FWindows%E3%81%A7%E3%81%AE%E3%83%95%E3%82%A1%E3%82%A4%E3%83%AB%E3%83%91%E3%82%B9
-
- chaichanPaPa, VtgJIS̃t@CɃ}b`Ă݂
- http://d.hatena.ne.jp/chaichanPaPa/20080802/1217660826
-
-  Iv, Jperl
- http://homepage2.nifty.com/kipp/perl/jperl/
-
- n , Jperl
- http://www.cpan.org/src/5.0/jperl/
- http://search.cpan.org/~watanabe/
- ftp://ftp.oreilly.co.jp/pcjp98/watanabe/jperlconf.ppt
-
- Chuck Houpt,  qq, MacJPerl
- http://habilis.net/macjperl/index.j.html
-
- Ί_ ꂳ, Pod-PerldocJp, _Perl̐Eւ悤
- http://search.cpan.org/dist/Pod-PerldocJp/
- http://gihyo.jp/dev/serial/01/modern-perl/0031
- http://gihyo.jp/dev/serial/01/modern-perl/0032
- http://gihyo.jp/dev/serial/01/modern-perl/0033
-
-  e, Encode W[
- http://search.cpan.org/dist/Encode/
- http://www.archive.org/details/YAPCAsia2006TokyoPerl58andUnicodeMythsFactsandChanges ()
- http://yapc.g.hatena.ne.jp/jkondo/ ()
-
- Juerd, Perl Unicode Advice
- http://juerd.nl/site.plp/perluniadvice
-
- daily dayflower, 2008-06-25 perluniadvice
- http://d.hatena.ne.jp/dayflower/20080625/1214374293
-
- Jesse Vincent, Compatibility is a virtue
- http://www.nntp.perl.org/group/perl.perl5.porters/2010/05/msg159825.html
-
  Tokyo-pm ۑ
  http://mail.pm.org/pipermail/tokyo-pm/
  http://mail.pm.org/pipermail/tokyo-pm/1999-September/001844.html
@@ -1848,5 +2021,161 @@ vO~O񋟂܂B
  http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/12393
  http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/19156
 
+ ֘A\tgEFA
+ http://search.cpan.org/dist/jacode/
+ http://search.cpan.org/dist/Char/
+
+ BackPAN
+ http://backpan.perl.org/authors/id/I/IN/INA/
+
+=head1 ӎ
+
+cOȂAӂ邷ׂĂ̐lɏƂł܂BƂāA
+𗝗RɂĈȉ̕Xւ̊ӂ͏ȗ킯ɂ͂Ȃł傤B
+
+ R Ǒ, VtgJIS̃fUC̘b
+ ttp://furukawablog.spaces.live.com/Blog/cns!1pmWgsL289nm7Shn7cS0jHzA!2225.entry (N؂)
+ ttp://shino.tumblr.com/post/116166805/1981-us-jis
+ (擪 'h' tăANZXĂ)
+ http://www.wdic.org/w/WDIC/%E3%82%B7%E3%83%95%E3%83%88JIS
+ 
+ {񏈗sہA܂ăVtgJISقǎpIȕ͂܂B
+ ő̗_͂锼pJ^JiƋł邱ƂłBߋ̎Y݂Ɍpł
+ ƂƂ́A݂̎Y𖢗֌pł邱ƂĂ܂B
+ 
+ 1981N̎_ŁA܂ōlĂR̓nbJ[ƌĂԂɂӂ킵ł傤B
+
+ Larry Wall , Perl
+ http://www.perl.org/
+ 
+ Perl K\ɂăoCif[^邱ƂŁÃ\tgEFAĂ
+ ܂Bo[WԂ̌݊̍ɂ܂BK\̃^eNH[
+ g̃f~^́AׂΏۂłŁAۂ̎iƂĂ𗧂܂B
+  Perl Ȃ΁A݂A܂тȂދȐl
+ ƂłB
+ 
+  Larry Wall ɂ͂ƂĂӂĂ܂I
+
+ ̑ a, jcode.pl
+ ftp://ftp.iij.ad.jp/pub/IIJ/dist/utashiro/perl/
+ http://log.utashiro.com/pub/2006/07/jkondo_a580.html
+ 
+ ŏ Perl ɏô͉̑コ̏ꂽ UNIX MAGAZINE ̋LłBt@C
+ eXgZq -TA-B ̋@\R[h͋Lɏꂽ̂قڂ̂܂܎g
+ ܂B܂{񏈗Mꂽ Ken Lunde ̐搶ł邵AJeffrey
+ E. F. Friedl ̏ڐK\̊ĖĂāÃ\tgEFA̎͂ɂ͕K
+ ̑コ񂪓oꂵ܂B
+ 
+ Tokyo.pm ̃[OXgł́AV@\邽߂ɐVɎꍇłA
+ ߋɍꂽ\tgEFAƓ̃C^tF[XɂƂA悢ACfBA
+ ܂B
+ 
+ قǎ͂ƌ܂A͓͂R̂ƂŁÃ\tgEFA jcode.pl 
+ \[XƂɂč쐬ꂽłB牽ǂlĂ̑コȂŁÃ\
+ tgEFA܂邱Ƃ͂Ȃ̂łB
+
+ Jeffrey E. F. Friedl , ڐK\
+ http://regex.info/
+ 
+ ڐK\(2)͂߂ēǂ񂾂ƂAĂ̂SłAĂ
+ pł𔃂Ă܂̂ł͂ȂƋ^قǂłBȂ P.340 Matching
+ Nested Constructs with Embedded Code KvƂĂR[hƋCÂƂ
+ ƂĂ̂oĂ܂(悭płł)B
+ 
+ Ȃ킯ŃlXgʂł̂́A}(Fumie)̂łB
+ (̊ӂ`܂悤...B)
+
+ Ken Lunde , {񏈗ACJKV؉z񏈗
+ http://www.fukkan.com/vote.php3?no=4293
+ http://www.oreilly.co.jp/books/4873111080/
+ 
+ u{񏈗vǂŕWKiƕwсAɂė[
+ ܂܂B̌̂ЂƂƂāup҂̈ӎvƈقȂA̕ϊv
+ ܂Bh߂ɁÃ\tgEFA͕ϊɏ񏈗
+ s܂B
+ 
+ Appendix W: Perl Code Examples ̒ CJKV Encoding TemplatesAMultiple-Byte
+ AnchoringAMultiple-Byte Processing ƂĂQlɂȂ܂B
+
+ A ms, Shift-JISeLXg𐳂
+ http://homepage1.nifty.com/nomenclator/perl/shiftjis.htm
+ 
+ uShift-JISeLXg𐳂vŁAPerlŃVtgJISƂ̃mEnE
+ A肪Ƃ܂B̃TCg̓eƂɁAXNvg̃e
+ ́u\vu\\vɕϊtB^vOƂ납n߁AO
+ ĂƂł̃\tgEFAĂ܂B
+
+ ܂ 䂫Ђ낳, Ruby on Perl(s)
+ http://www.rubyist.net/~matz/slides/yapc2006/
+ 
+ YAPC::Asia 2006 Tokyo "Ruby on Perl(s)" ŁuCSI͕s\ȂvƂ𕪂₷
+ Ă炢܂Bx Ruby ł܂̂ł낵肢܂B
+
+  av, jperl[U[̂߂
+ http://homepage1.nifty.com/kazuf/jperl.html
+ 
+ ver.0.71 쐬ہAڗpłȂł̃eXĝ߂60̃[
+ AJɃfobOɕtĒ܂B肪Ƃ܂B
+
+ Bruce. , Unicode in Perl
+ http://www.rakunet.org/tsnet/TSabc/18/546.html
+
+ a G, WindowsPerl 5.8/5.10gȂ
+ http://www.aritia.jp/hizumi/perl/perlwin.html
+
+ ˖{ q, Perl/Windowsł̃t@CpX
+ http://digit.que.ne.jp/work/wiki.cgi?Perl%E3%83%A1%E3%83%A2%2FWindows%E3%81%A7%E3%81%AE%E3%83%95%E3%82%A1%E3%82%A4%E3%83%AB%E3%83%91%E3%82%B9
+
+ chaichanPaPa, VtgJIS̃t@CɃ}b`Ă݂
+ http://d.hatena.ne.jp/chaichanPaPa/20080802/1217660826
+
+  Iv, Jperl
+ http://homepage2.nifty.com/kipp/perl/jperl/
+
+ n , Jperl
+ http://www.cpan.org/src/5.0/jperl/
+ http://search.cpan.org/~watanabe/
+ ftp://ftp.oreilly.co.jp/pcjp98/watanabe/jperlconf.ppt
+ 
+ The Perl Confernce Japan (1998)JperlJ̌o܂𕷂Ă炢܂BJPerl 
+ ́A{Ήł Perl ͂ǂ̂悤Ȃ̂g₷̂܂Btr///b 
+ ord  reverse ݂ JPerl ̓^܂(ŃeXgvO܂
+ 炤Ƃł܂)B
+ 
+ nӂ̂ƂƓN񂶂Ȃ()҂Ă킯łA
+ ҂ĂԂ Perl Ńvg^CvĂ܂B҂̂͊yƂłB
+
+ Chuck Houpt ,  qq, MacJPerl
+ http://habilis.net/macjperl/index.j.html
+
+ Ί_ ꂳ, Pod-PerldocJp, _Perl̐Eւ悤
+ http://search.cpan.org/dist/Pod-PerldocJp/
+ http://gihyo.jp/dev/serial/01/modern-perl/0031
+ http://gihyo.jp/dev/serial/01/modern-perl/0032
+ http://gihyo.jp/dev/serial/01/modern-perl/0033
+ 
+ u_Perl̐Eւ悤v̘AڂƂĂQlɂȂ܂Bɑ31񂩂33
+ JPerl Ɋ֘AeŁAZpIɂjIɂƂĂkȋLłB
+ 
+ ̃\tgEFA_Perlւ̉˂ƂĖ𗧂Ă΍KłB
+
+  e, Encode W[
+ http://search.cpan.org/dist/Encode/
+ http://www.archive.org/details/YAPCAsia2006TokyoPerl58andUnicodeMythsFactsandChanges ()
+ http://yapc.g.hatena.ne.jp/jkondo/ ()
+ 
+ YAPC::Asia 2006 Tokyo "Perl5.8 and Unicode: Myths, Facts and Changes"  Perl5.8
+ ł̕ύX_ڂĂ炢܂BCPAN  face icon ͂̃XChɏoĂ
+ Perl5.6 = a city without bridges ̉摜qg𓾂Ă܂B
+
+ Juerd , Perl Unicode Advice
+ http://juerd.nl/site.plp/perluniadvice
+
+ daily dayflower , 2008-06-25 perluniadvice
+ http://d.hatena.ne.jp/dayflower/20080625/1214374293
+
+ Jesse Vincent , Compatibility is a virtue
+ http://www.nntp.perl.org/group/perl.perl5.porters/2010/05/msg159825.html
+
 =cut
 
